@@ -3,4 +3,4 @@ Created on 15 mars 2016
 
 @author: alain
 '''
-from caraf import Caraf
\ No newline at end of file
+from .caraf import Caraf
\ No newline at end of file
